Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1897)

Unified Diff: appengine/findit/crash/test/crash_test_suite.py

Issue 2586343002: renamed the "Suspects" class to "SuspectMap", to reduce confusion. (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « appengine/findit/crash/suspect.py ('k') | appengine/findit/crash/test/suspect_test.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: appengine/findit/crash/test/crash_test_suite.py
diff --git a/appengine/findit/crash/test/crash_test_suite.py b/appengine/findit/crash/test/crash_test_suite.py
index 7c847e12798b624d88bcbb5d4a0aca1de8c1cfb4..b619f8cd30898c4015a1d57f973acea97d011a28 100644
--- a/appengine/findit/crash/test/crash_test_suite.py
+++ b/appengine/findit/crash/test/crash_test_suite.py
@@ -43,8 +43,8 @@ class CrashTestSuite(StacktraceTestSuite): # pragma: no cover.
self.assertEqual(suspect1.file_to_analysis_info,
suspect2.file_to_analysis_info)
- def _VerifyTwoSuspectsEqual(self, suspects1, suspects2):
- """Assert that two ``Suspects`` objects are equal."""
+ def _VerifyTwoSuspectMapEqual(self, suspects1, suspects2):
+ """Assert that two ``SuspectMap`` objects are equal."""
self.assertEqual(suspects1._ignore_cls, suspects2._ignore_cls)
self.assertEqual(len(suspects1), len(suspects2))
« no previous file with comments | « appengine/findit/crash/suspect.py ('k') | appengine/findit/crash/test/suspect_test.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698